Textory
=======

.. image:: https://travis-ci.org/BENR0/textory.svg?branch=master
    :target: https://travis-ci.org/BENR0/textory

.. image:: https://badge.fury.io/py/textory.svg
    :target: https://badge.fury.io/py/textory

.. image:: https://codecov.io/gh/BENR0/textory/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/BENR0/textory

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3653939.svg
   :target: https://doi.org/10.5281/zenodo.3653939

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
   :target: https://opensource.org/licenses/MIT

Textory is a python library for the calculation of windowed statistics of arrays.
It can calculate windowed variograms, pseudo-cross variograms and standard statistics like
mean, std, min, max, etc. for rectangular and round windows.
It can also be used conveniently with xarrays and Satpy scenes.

Documentation is available at https://textory.readthedocs.io.


Installation
------------

Textory can be installed from PyPI with pip: 

.. code-block:: bash

    pip install textory

